function [vPeriod, vAcc,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel)
% [vPeriod, vAcc,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel)
% -------------------------------------------------------------------------
% Function to extract Uniform Hazard Specrum data from EFEHR-portal
% database for one location. Web-service searches closest location to
% extract data.
%
% Input parameters:
% fLon: geogr. Longitude
% fLat: geogr. Latitude
% sIMT: Intensity measure type, e.g. SA for spectral acceleration (default)
% fPoE: PRobability of exceedance in fPeriod, e.g. 0.1 for 10% in fPeriod 
% fPeriod: Period in years, e.g. 50 years (only available)
% sSoilType: Soil class, e.g. default 'rock'
% sAggregationType: ordinal, arithmetic
% fAggLevel: Fractile (0.05, 0.15, 0.5, 0.85, 0.95)
%
% Output data:
% vPeriod: Vector of spectral periods in seconds
% vAcc: Vector with spectral acceleration in g
% sLoc: Location of the exact point (Lon Lat)
%
% Example:
% function [vPeriod, vAcc,sLoc] = GetEfehrUhs(48.35,8.51,'SA',0.1,50,'rock','arithmetic',0.5)
% Delivers UHS data at the location 48.35N / 8.51E for 10% in 50y on rock, delivering the arithmetic mean (0.5) 
%
% Copyright (C) 2010 by J. Woessner
% 12.08.2013
% j.woessner@sed.ethz.ch
%
%% Licence
% SHARE data and products are released under the Creative Commons 
% Attribution-ShareAlike 3.0 Unported (CC BY-SA 3.0) licence.
%  
% For all SHARE datasets the following notice applies and/or is included within the files:
%  
% Copyright ? 2013, ETH Zurich on behalf of the EU-FP7 Consortium of SHARE
% 
% You may use this work under the terms of the CC BY-SA 3.0 (unported) 
% [http://creativecommons.org/licenses/by-sa/3.0/]
% 
% THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. INSOFAR 
% AS THIS WORK IS PROTECTED BY LAWS THAT NEIGHBOUR OR ARE SIMILARLY RELATED
% TO COPYRIGHT, SUCH AS DATABASE RIGHTS AS INTRODUCED IN EUROPE BY THE  
% DIRECTIVE 96/9/EC, YOU ALSO MAY USE THIS WORK UNDER THE TERMS OF 
% CC-BY-SA 3.0 (unported).
% 
% ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR 
% DIRECTLY ALLOWED BY THE APPLICABLE LAW IS PROHIBITED.
% 
% If you alter, transform, or build upon this work, you may distribute the 
% resulting work only under the same or similar license to this one. 
% 
% If you have any questions, or if you wish to seek permission to use this 
% data beyond what is offered by CC BY-SA 3.0 (unported), please contact 
% representatives of the EU-FP7 SHARE consortium at: 
% 
%  
% ETH Zurich / Swiss Seismological Service
% Sonneggstrasse 5
% CH-8092 Zurich, Switzerland
% email: share@sed.ethz.ch
% Tel.: +41-44-633-2179

%% Download data using webservice of EFEHR
sUrl = ['http://appsrvr.share-eu.org:8080/share/'];
% 1. Get available model ID(s) for the location
sUrlModel = [sUrl 'spectra?lat=' num2str(fLat) '&lon=' num2str(fLon)];

% Write to xml-file
urlwrite(sUrlModel,'TMPmodel.xml');
m=xmlread('TMPmodel.xml');
fModel=m.getElementsByTagName('id').item(0).getTextContent;

% Define dowload string
sUHS = ['http://appsrvr.share-eu.org:8080/share/spectra?&lat=' num2str(fLat) '&lon=' num2str(fLon) '&id=' char(fModel) '&imt=' sIMT '&poe=' num2str(fPoE) '&timespanpoe=' num2str(fPeriod) '&soiltype=' sSoilType '&aggregationtype=' sAggregationType '&aggregationlevel=' num2str(fAggLevel)];
%urlwrite('http://appsrvr.share-eu.org:8080/share/spectra?lat=42.5&lon=7.6&id=68&imt=SA&poe=0.02&timespanpoe=50&soiltype=rock&aggregationtype=arithmetic&aggregationlevel=0.5')

% Get data via webservice and write to XML-file
urlwrite(sUHS,'TMPuhs.xml');
% Read back XML-data
DOM = xmlread('TMPuhs.xml');
% Get data from the xml-data
vPeriod=DOM.getElementsByTagName('ns2:spectraPeriodList').item(0).getTextContent;
vAcc = DOM.getElementsByTagName('ns2:IML').item(0).getTextContent;
sLoc = DOM.getElementsByTagName('ns1:pos').item(0).getTextContent;